
/*=============================================================
Authour URL: www.designbootstrap.com

http://www.designbootstrap.com/

License: MIT

http://opensource.org/licenses/MIT

100% Free To use For Personal And Commercial Use.

IN EXCHANGE JUST TELL PEOPLE ABOUT THIS WEBSITE

========================================================  */
r

/* =============================================================
GENERAL STYLES
============================================================ */

@import url(http://fonts.googleapis.com/css?family=Roboto); /* FREE GOOGLE FONT */

body {
    font-family: 'Roboto', sans-serif;
    line-height: 30px;
    background-color: var(--color_background);
}

.pace-done {
    background-color: var(--color_background);
}

.content-wrapper {
    background-color: var(--color_background);
}

a {
    text-decoration: none !important;
    color: rgb(35, 82, 124);
}

.set-radius-zero {
    border-radius: 0px;
    -moz-border-radius: 0px;
    -webkit-border-radius: 0px;
}

.content-wrapper {
    margin-top: 40px;
    min-height: 600px;
    padding-bottom: 60px;
}

.page-head-line {
    font-weight: 900;
    padding-bottom: 20px;
    border-bottom: 2px solid #81c784;
    text-transform: uppercase;
    color: #81c784;
    font-size: 20px;
    margin-bottom: 40px;
}

.btn {
    border-radius: 0px;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
}

.progress {
    height: 8px;
    border-radius: 0px;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
}
.login-icon {
    height: 60px;
    width: 60px;
    padding: 13px;
    border-radius: 50%;
    font-size: 30px;
    margin-bottom: 20px;
    color: #fff;
    text-align: center;
    cursor:pointer;
    background-color:#81c784;
    -webkit-border-radius:50%;
    -moz-border-radius:50%;
}
/* =============================================================
HEADER SECTION STYLES
============================================================ */
header {
    background-color: #81c784;
    color: #fff;
    padding: 10px;
    text-align: right;
}


/* =============================================================
LOGO SECTION STYLES
============================================================ */
.left-div {
    padding-left: 30px;
    margin-top: 40px;
    margin-bottom: 30px;
}

.navbar-brand {
    width: 250px;
    padding-top: 30px;
    float: left;
    height: 50px;
    font-size: 18px;
    line-height: 20px;
}

/* USER SETTINGS DIV */
.user-settings-wrapper .nav > li > a {
    position: relative;
    display: block;
    padding: 15px 18px;
    border-radius: 50%;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    height: 60px;
    width: 60px;
    background-color: #81c784;
    color: #fff;
}

.user-settings-wrapper {
    margin-top: 10px;
}

.user-settings-wrapper li {
    display: inline-block;
}

.user-settings-wrapper .dropdown-settings {
    width: 200px;
    padding: 10px;
}

.user-settings-wrapper .nav > li > a:hover,.user-settings-wrapper .nav > li > a:focus {
    text-decoration: none;
    background-color: #4caf50!important;
}

.user-settings-wrapper img {
    height: 64px;
    width: 64px;
    border: 1px solid #000000;
}

.user-settings-wrapper .dropdown-menu {
    margin: 0px;
    border-radius: 0px!important;
    -moz-border-radius: 0px!important;
    -webkit-border-radius: 0px!important;
}

.user-settings-wrapper .btn {
    border-radius: 0px!important;
    -moz-border-radius: 0px!important;
    -webkit-border-radius: 0px!important;
}

.user-settings-wrapper .media-heading {
    padding-top: 10px;
}

/* MENU LINKS SECTION*/

.menu-section {
    background-color: #3D3D3D;
}

#menu-top a {
    color: #FFF;
    text-decoration: none;
    font-weight: 500;
    padding: 10px 10px 10px 10px;
    text-transform: uppercase;
}

.menu-top-active {
    background-color: #4caf50;
}

.menu-section .nav > li > a:hover,.menu-section .nav > li > a:focus {
    background-color: var(--color_accent) !important;
}

.menu-section .dropdown-menu > li > a:hover,.menu-section .dropdown-menu > li > a:focus {
    background-color: var(--color_accent) !important;
}

.navbar-inverse {
    background-color: #4caf50;
    border-color: transparent;
}

.navbar-toggle {
    background-color: #81c784;
    border: 1px solid #fff;
}

.navbar {
    margin-bottom: 0px;
}
/* =============================================================
FOOTER SECTION STYLES
============================================================ */
footer {
    padding: 10px;
    color: #fff;
    font-size: 12px;
    background-color: #4caf50;
}

footer a, footer a:hover {
    color: #fff;
    text-decoration: none;
}

/*==============================================
DASHBOARD  STYLES    
=============================================*/

/* DASHBOARD ICONS */

.bk-clr-one {
    background-color: #B9B739;
}

.bk-clr-two {
    background-color: #F94C4C;
}

.bk-clr-three {
    background-color: #119c7e;
}

.bk-clr-four {
    background-color: #b739b9;
}

.dashboard-div-icon {
    height: 75px;
    width: 75px;
    border: 2px solid #fff;
    padding: 20px;
    border-radius: 50%;
    -webkit-border-radius:50%;
    -moz-border-radius:50%;
    font-size: 30px;
    margin-bottom: 20px;
    color: #fff;
}

.dashboard-div-wrapper {
    border-radius: 5px;
    text-align: center;
    padding: 15px;
    color: #fff;
    margin-bottom: 50px;
}

.dashboard-div-wrapper .progress {
    height: 2px;
}

/* NOTICE BOARD */


.notice-board .panel {
    border-radius: 0px;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
}

.notice-board ul {
    padding-left: 0px;
    list-style: none;
}

.notice-board li {
    padding: 10px;
    border-bottom: 1px solid #E5E5E5;
}

.notice-board li span {
    margin-right: 10px;
    border: 1px solid #DBDBDB;
    padding: 5px;
}

.notice-board li a, li a:hover {
    text-decoration: none;
    color: #000;
}

/* SOCIAL BUTTONS */
.btn-social {
    color: white;
    opacity: 0.8;
}

.btn-social:hover {
    color: white;
    opacity: 1;
    text-decoration: none;
}

.btn-facebook {
    background-color: #3b5998;
}

.btn-twitter {
    background-color: #00aced;
}

.btn-linkedin {
    background-color: #0e76a8;
}

.btn-google {
    background-color: #c32f10;
}

.sequence {
    font-family: monospace;
}

#back {
    margin-bottom: 20px;
}

.errors {
    margin-top: 20px;
}

.pagination-section input {
    width:100%;
}

.panel-title .row .col-md-11,
.panel-title .row .col-md-10 a {
    color: rgb(35, 82, 124);
}

.panel-title a {
    color: rgb(35, 82, 124);
}

.panel-body {
    background-color: var(--color_background);
}

#organismImage {
    width:100%;
    height:100%;
}

header {
    background-color: var(--color_accent);
    color: var(--color_accent_text);
}

header a {
    color: var(--color_accent_text);
}

.navbar-inverse {
    background-color: var(--color_primary);
}

.navbar-inverse .navbar-brand {
    color: var(--color_primary_text);
}

.menu-section {
    background-color: var(--color_menu);
    color: var(--color_primary_text);
}

.menu-top-active {
    background-color: var(--color_primary);
    color: var(--color_primary_text); 
}

.menu-section .nav > li > a:hover,
.menu-section .nav > li > a:focus {
    background-color: var(--color_accent) !important;
}

footer, 
footer a, 
footer a:hover, 
footer a:focus{
    background-color: var(--color_footer);
    color: var(--color_footer_text);
}

.page-head-line {
    color: var(--color_accent);
    border-bottom: 2px solid var(--color_accent);
}

.navbar-toggle {
    background-color: var(--color_accent);
}


